# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: morai_sim_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import morai_type_pb2 as morai__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14morai_sim_info.proto\x12\rmorai_sim_api\x1a\x1bgoogle/protobuf/empty.proto\x1a\x10morai_type.proto\"s\n\x11\x43\x61tegoryObstacles\x12\x0f\n\x07vehicle\x18\x01 \x01(\x08\x12\x12\n\npedestrian\x18\x02 \x01(\x08\x12\x10\n\x08obstacle\x18\x03 \x01(\x08\x12\x13\n\x0bspawn_point\x18\x04 \x01(\x08\x12\x12\n\nmap_object\x18\x05 \x01(\x08\"q\n\x0f\x41vailableObject\x12\x0f\n\x07vehicle\x18\x01 \x03(\t\x12\x12\n\npedestrian\x18\x02 \x03(\t\x12\x10\n\x08obstacle\x18\x03 \x03(\t\x12\x13\n\x0bspawn_point\x18\x04 \x03(\t\x12\x12\n\nmap_object\x18\x05 \x03(\t2\xce\x03\n\x0cMoraiSimInfo\x12K\n\x13GetSimulatorVersion\x12\x16.google.protobuf.Empty\x1a\x1a.morai_sim_api.StringValue\"\x00\x12\x43\n\x0cGetTimestamp\x12\x16.google.protobuf.Empty\x1a\x19.morai_sim_api.Int64Value\"\x00\x12G\n\x10GetAvailableMaps\x12\x16.google.protobuf.Empty\x1a\x19.morai_sim_api.StringList\"\x00\x12\x44\n\rGetActorTypes\x12\x16.google.protobuf.Empty\x1a\x19.morai_sim_api.StringList\"\x00\x12X\n\x12GetAvailableObject\x12 .morai_sim_api.CategoryObstacles\x1a\x1e.morai_sim_api.AvailableObject\"\x00\x12\x43\n\x0bGetDataPath\x12\x16.google.protobuf.Empty\x1a\x1a.morai_sim_api.StringValue\"\x00\x42&H\x01\xaa\x02!CoreLib.Grpc.Protobuf.MoraiSimAPIb\x06proto3')



_CATEGORYOBSTACLES = DESCRIPTOR.message_types_by_name['CategoryObstacles']
_AVAILABLEOBJECT = DESCRIPTOR.message_types_by_name['AvailableObject']
CategoryObstacles = _reflection.GeneratedProtocolMessageType('CategoryObstacles', (_message.Message,), {
  'DESCRIPTOR' : _CATEGORYOBSTACLES,
  '__module__' : 'morai_sim_info_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.CategoryObstacles)
  })
_sym_db.RegisterMessage(CategoryObstacles)

AvailableObject = _reflection.GeneratedProtocolMessageType('AvailableObject', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLEOBJECT,
  '__module__' : 'morai_sim_info_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.AvailableObject)
  })
_sym_db.RegisterMessage(AvailableObject)

_MORAISIMINFO = DESCRIPTOR.services_by_name['MoraiSimInfo']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\252\002!CoreLib.Grpc.Protobuf.MoraiSimAPI'
  _CATEGORYOBSTACLES._serialized_start=86
  _CATEGORYOBSTACLES._serialized_end=201
  _AVAILABLEOBJECT._serialized_start=203
  _AVAILABLEOBJECT._serialized_end=316
  _MORAISIMINFO._serialized_start=319
  _MORAISIMINFO._serialized_end=781
# @@protoc_insertion_point(module_scope)
