# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: morai_mgeo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import morai_type_pb2 as morai__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10morai_mgeo.proto\x12\rmorai_sim_api\x1a\x10morai_type.proto\"\x1b\n\x07MapInfo\x12\x10\n\x08map_name\x18\x01 \x01(\t\"\xdb\x01\n\x08MGeoData\x12\x13\n\x0bglobal_info\x18\x01 \x01(\t\x12\x18\n\x10lane_marking_set\x18\x02 \x01(\t\x12\x15\n\rlane_node_set\x18\x03 \x01(\t\x12\x11\n\tlinke_set\x18\x04 \x01(\t\x12\x10\n\x08node_set\x18\x05 \x01(\t\x12\x19\n\x11traffic_light_set\x18\x06 \x01(\t\x12#\n\x1bintersection_controller_set\x18\x07 \x01(\t\x12$\n\x1cintersection_controller_data\x18\x08 \x01(\t\"4\n\x0fGetLinkResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x11\n\tunique_id\x18\x02 \x01(\t\"P\n\x13GetLinkResponseList\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12)\n\x08res_list\x18\x02 \x03(\x0b\x32\x17.morai_sim_api.LinkInfo\" \n\x0bVehicleInfo\x12\x11\n\tunique_id\x18\x01 \x01(\t\"]\n\x1dGetVehiclesOnLinkResponseList\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12,\n\x08res_list\x18\x02 \x03(\x0b\x32\x1a.morai_sim_api.VehicleInfo2\xd8\x03\n\tMoraiMgeo\x12<\n\x07GetMGeo\x12\x16.morai_sim_api.MapInfo\x1a\x17.morai_sim_api.MGeoData\"\x00\x12H\n\x0bGetLeftLink\x12\x17.morai_sim_api.LinkInfo\x1a\x1e.morai_sim_api.GetLinkResponse\"\x00\x12I\n\x0cGetRightLink\x12\x17.morai_sim_api.LinkInfo\x1a\x1e.morai_sim_api.GetLinkResponse\"\x00\x12K\n\nGetToLinks\x12\x17.morai_sim_api.LinkInfo\x1a\".morai_sim_api.GetLinkResponseList\"\x00\x12M\n\x0cGetFromLinks\x12\x17.morai_sim_api.LinkInfo\x1a\".morai_sim_api.GetLinkResponseList\"\x00\x12\\\n\x11GetVehiclesOnLink\x12\x17.morai_sim_api.LinkInfo\x1a,.morai_sim_api.GetVehiclesOnLinkResponseList\"\x00\x42&H\x01\xaa\x02!CoreLib.Grpc.Protobuf.MoraiSimAPIb\x06proto3')



_MAPINFO = DESCRIPTOR.message_types_by_name['MapInfo']
_MGEODATA = DESCRIPTOR.message_types_by_name['MGeoData']
_GETLINKRESPONSE = DESCRIPTOR.message_types_by_name['GetLinkResponse']
_GETLINKRESPONSELIST = DESCRIPTOR.message_types_by_name['GetLinkResponseList']
_VEHICLEINFO = DESCRIPTOR.message_types_by_name['VehicleInfo']
_GETVEHICLESONLINKRESPONSELIST = DESCRIPTOR.message_types_by_name['GetVehiclesOnLinkResponseList']
MapInfo = _reflection.GeneratedProtocolMessageType('MapInfo', (_message.Message,), {
  'DESCRIPTOR' : _MAPINFO,
  '__module__' : 'morai_mgeo_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.MapInfo)
  })
_sym_db.RegisterMessage(MapInfo)

MGeoData = _reflection.GeneratedProtocolMessageType('MGeoData', (_message.Message,), {
  'DESCRIPTOR' : _MGEODATA,
  '__module__' : 'morai_mgeo_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.MGeoData)
  })
_sym_db.RegisterMessage(MGeoData)

GetLinkResponse = _reflection.GeneratedProtocolMessageType('GetLinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLINKRESPONSE,
  '__module__' : 'morai_mgeo_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.GetLinkResponse)
  })
_sym_db.RegisterMessage(GetLinkResponse)

GetLinkResponseList = _reflection.GeneratedProtocolMessageType('GetLinkResponseList', (_message.Message,), {
  'DESCRIPTOR' : _GETLINKRESPONSELIST,
  '__module__' : 'morai_mgeo_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.GetLinkResponseList)
  })
_sym_db.RegisterMessage(GetLinkResponseList)

VehicleInfo = _reflection.GeneratedProtocolMessageType('VehicleInfo', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEINFO,
  '__module__' : 'morai_mgeo_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleInfo)
  })
_sym_db.RegisterMessage(VehicleInfo)

GetVehiclesOnLinkResponseList = _reflection.GeneratedProtocolMessageType('GetVehiclesOnLinkResponseList', (_message.Message,), {
  'DESCRIPTOR' : _GETVEHICLESONLINKRESPONSELIST,
  '__module__' : 'morai_mgeo_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.GetVehiclesOnLinkResponseList)
  })
_sym_db.RegisterMessage(GetVehiclesOnLinkResponseList)

_MORAIMGEO = DESCRIPTOR.services_by_name['MoraiMgeo']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\252\002!CoreLib.Grpc.Protobuf.MoraiSimAPI'
  _MAPINFO._serialized_start=53
  _MAPINFO._serialized_end=80
  _MGEODATA._serialized_start=83
  _MGEODATA._serialized_end=302
  _GETLINKRESPONSE._serialized_start=304
  _GETLINKRESPONSE._serialized_end=356
  _GETLINKRESPONSELIST._serialized_start=358
  _GETLINKRESPONSELIST._serialized_end=438
  _VEHICLEINFO._serialized_start=440
  _VEHICLEINFO._serialized_end=472
  _GETVEHICLESONLINKRESPONSELIST._serialized_start=474
  _GETVEHICLESONLINKRESPONSELIST._serialized_end=567
  _MORAIMGEO._serialized_start=570
  _MORAIMGEO._serialized_end=1042
# @@protoc_insertion_point(module_scope)
