# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import morai_sim_info_pb2 as morai__sim__info__pb2
import morai_type_pb2 as morai__type__pb2


class MoraiSimInfoStub(object):
    """MORAI SIM 정보 확인을 위한 서비스
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetSimulatorVersion = channel.unary_unary(
                '/morai_sim_api.MoraiSimInfo/GetSimulatorVersion',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.StringValue.FromString,
                )
        self.GetTimestamp = channel.unary_unary(
                '/morai_sim_api.MoraiSimInfo/GetTimestamp',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.Int64Value.FromString,
                )
        self.GetAvailableMaps = channel.unary_unary(
                '/morai_sim_api.MoraiSimInfo/GetAvailableMaps',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.StringList.FromString,
                )
        self.GetActorTypes = channel.unary_unary(
                '/morai_sim_api.MoraiSimInfo/GetActorTypes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.StringList.FromString,
                )
        self.GetAvailableObject = channel.unary_unary(
                '/morai_sim_api.MoraiSimInfo/GetAvailableObject',
                request_serializer=morai__sim__info__pb2.CategoryObstacles.SerializeToString,
                response_deserializer=morai__sim__info__pb2.AvailableObject.FromString,
                )
        self.GetDataPath = channel.unary_unary(
                '/morai_sim_api.MoraiSimInfo/GetDataPath',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.StringValue.FromString,
                )


class MoraiSimInfoServicer(object):
    """MORAI SIM 정보 확인을 위한 서비스
    """

    def GetSimulatorVersion(self, request, context):
        """시뮬레이터 버전 확인
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTimestamp(self, request, context):
        """시뮬레이터의 Timestamp 확인
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAvailableMaps(self, request, context):
        """현재 사용자가 사용 가능한 맵 리스트 조회
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActorTypes(self, request, context):
        """시뮬레이터에서 사용 가능한 Actor 종류 조회
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAvailableObject(self, request, context):
        """Get Available Object matched to the user account info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataPath(self, request, context):
        """데이터 저장 경로 획득
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MoraiSimInfoServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetSimulatorVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSimulatorVersion,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.StringValue.SerializeToString,
            ),
            'GetTimestamp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTimestamp,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.Int64Value.SerializeToString,
            ),
            'GetAvailableMaps': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableMaps,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.StringList.SerializeToString,
            ),
            'GetActorTypes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActorTypes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.StringList.SerializeToString,
            ),
            'GetAvailableObject': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableObject,
                    request_deserializer=morai__sim__info__pb2.CategoryObstacles.FromString,
                    response_serializer=morai__sim__info__pb2.AvailableObject.SerializeToString,
            ),
            'GetDataPath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataPath,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.StringValue.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'morai_sim_api.MoraiSimInfo', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MoraiSimInfo(object):
    """MORAI SIM 정보 확인을 위한 서비스
    """

    @staticmethod
    def GetSimulatorVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimInfo/GetSimulatorVersion',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.StringValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTimestamp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimInfo/GetTimestamp',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.Int64Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAvailableMaps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimInfo/GetAvailableMaps',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.StringList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActorTypes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimInfo/GetActorTypes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.StringList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAvailableObject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimInfo/GetAvailableObject',
            morai__sim__info__pb2.CategoryObstacles.SerializeToString,
            morai__sim__info__pb2.AvailableObject.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataPath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimInfo/GetDataPath',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.StringValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
