# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: morai_type.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10morai_type.proto\x12\rmorai_sim_api\".\n\x06Result\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"(\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"*\n\x07Vector3\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"_\n\tTransform\x12(\n\x08location\x18\x01 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12(\n\x08rotation\x18\x02 \x01(\x0b\x32\x16.morai_sim_api.Vector3\"\x89\x01\n\x0b\x42oundingBox\x12&\n\x06\x65xtent\x18\x01 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12(\n\x08location\x18\x02 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12(\n\x08rotation\x18\x03 \x01(\x0b\x32\x16.morai_sim_api.Vector3\"\x1c\n\x0bStringValue\x12\r\n\x05value\x18\x01 \x01(\t\"\x1c\n\nStringList\x12\x0e\n\x06values\x18\x01 \x03(\t\"\x1b\n\nInt32Value\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1b\n\nInt64Value\x12\r\n\x05value\x18\x01 \x01(\x03\"\x1c\n\x0bUint32Value\x12\r\n\x05value\x18\x01 \x01(\r\"\x1c\n\x0bUint64Value\x12\r\n\x05value\x18\x01 \x01(\x04\"\x1b\n\nFloatValue\x12\r\n\x05value\x18\x01 \x01(\x02\"\x1c\n\x0b\x44oubleValue\x12\r\n\x05value\x18\x01 \x01(\x02\"\x1a\n\tBoolValue\x12\r\n\x05value\x18\x01 \x01(\x08\"3\n\x08LinkInfo\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x14\n\x0cwaypoint_idx\x18\x02 \x01(\x05\x42&H\x01\xaa\x02!CoreLib.Grpc.Protobuf.MoraiSimAPIb\x06proto3')



_RESULT = DESCRIPTOR.message_types_by_name['Result']
_POINT = DESCRIPTOR.message_types_by_name['Point']
_VECTOR3 = DESCRIPTOR.message_types_by_name['Vector3']
_TRANSFORM = DESCRIPTOR.message_types_by_name['Transform']
_BOUNDINGBOX = DESCRIPTOR.message_types_by_name['BoundingBox']
_STRINGVALUE = DESCRIPTOR.message_types_by_name['StringValue']
_STRINGLIST = DESCRIPTOR.message_types_by_name['StringList']
_INT32VALUE = DESCRIPTOR.message_types_by_name['Int32Value']
_INT64VALUE = DESCRIPTOR.message_types_by_name['Int64Value']
_UINT32VALUE = DESCRIPTOR.message_types_by_name['Uint32Value']
_UINT64VALUE = DESCRIPTOR.message_types_by_name['Uint64Value']
_FLOATVALUE = DESCRIPTOR.message_types_by_name['FloatValue']
_DOUBLEVALUE = DESCRIPTOR.message_types_by_name['DoubleValue']
_BOOLVALUE = DESCRIPTOR.message_types_by_name['BoolValue']
_LINKINFO = DESCRIPTOR.message_types_by_name['LinkInfo']
Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Result)
  })
_sym_db.RegisterMessage(Result)

Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
  'DESCRIPTOR' : _POINT,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Point)
  })
_sym_db.RegisterMessage(Point)

Vector3 = _reflection.GeneratedProtocolMessageType('Vector3', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR3,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Vector3)
  })
_sym_db.RegisterMessage(Vector3)

Transform = _reflection.GeneratedProtocolMessageType('Transform', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORM,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Transform)
  })
_sym_db.RegisterMessage(Transform)

BoundingBox = _reflection.GeneratedProtocolMessageType('BoundingBox', (_message.Message,), {
  'DESCRIPTOR' : _BOUNDINGBOX,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.BoundingBox)
  })
_sym_db.RegisterMessage(BoundingBox)

StringValue = _reflection.GeneratedProtocolMessageType('StringValue', (_message.Message,), {
  'DESCRIPTOR' : _STRINGVALUE,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.StringValue)
  })
_sym_db.RegisterMessage(StringValue)

StringList = _reflection.GeneratedProtocolMessageType('StringList', (_message.Message,), {
  'DESCRIPTOR' : _STRINGLIST,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.StringList)
  })
_sym_db.RegisterMessage(StringList)

Int32Value = _reflection.GeneratedProtocolMessageType('Int32Value', (_message.Message,), {
  'DESCRIPTOR' : _INT32VALUE,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Int32Value)
  })
_sym_db.RegisterMessage(Int32Value)

Int64Value = _reflection.GeneratedProtocolMessageType('Int64Value', (_message.Message,), {
  'DESCRIPTOR' : _INT64VALUE,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Int64Value)
  })
_sym_db.RegisterMessage(Int64Value)

Uint32Value = _reflection.GeneratedProtocolMessageType('Uint32Value', (_message.Message,), {
  'DESCRIPTOR' : _UINT32VALUE,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Uint32Value)
  })
_sym_db.RegisterMessage(Uint32Value)

Uint64Value = _reflection.GeneratedProtocolMessageType('Uint64Value', (_message.Message,), {
  'DESCRIPTOR' : _UINT64VALUE,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Uint64Value)
  })
_sym_db.RegisterMessage(Uint64Value)

FloatValue = _reflection.GeneratedProtocolMessageType('FloatValue', (_message.Message,), {
  'DESCRIPTOR' : _FLOATVALUE,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.FloatValue)
  })
_sym_db.RegisterMessage(FloatValue)

DoubleValue = _reflection.GeneratedProtocolMessageType('DoubleValue', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEVALUE,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.DoubleValue)
  })
_sym_db.RegisterMessage(DoubleValue)

BoolValue = _reflection.GeneratedProtocolMessageType('BoolValue', (_message.Message,), {
  'DESCRIPTOR' : _BOOLVALUE,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.BoolValue)
  })
_sym_db.RegisterMessage(BoolValue)

LinkInfo = _reflection.GeneratedProtocolMessageType('LinkInfo', (_message.Message,), {
  'DESCRIPTOR' : _LINKINFO,
  '__module__' : 'morai_type_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.LinkInfo)
  })
_sym_db.RegisterMessage(LinkInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\252\002!CoreLib.Grpc.Protobuf.MoraiSimAPI'
  _RESULT._serialized_start=35
  _RESULT._serialized_end=81
  _POINT._serialized_start=83
  _POINT._serialized_end=123
  _VECTOR3._serialized_start=125
  _VECTOR3._serialized_end=167
  _TRANSFORM._serialized_start=169
  _TRANSFORM._serialized_end=264
  _BOUNDINGBOX._serialized_start=267
  _BOUNDINGBOX._serialized_end=404
  _STRINGVALUE._serialized_start=406
  _STRINGVALUE._serialized_end=434
  _STRINGLIST._serialized_start=436
  _STRINGLIST._serialized_end=464
  _INT32VALUE._serialized_start=466
  _INT32VALUE._serialized_end=493
  _INT64VALUE._serialized_start=495
  _INT64VALUE._serialized_end=522
  _UINT32VALUE._serialized_start=524
  _UINT32VALUE._serialized_end=552
  _UINT64VALUE._serialized_start=554
  _UINT64VALUE._serialized_end=582
  _FLOATVALUE._serialized_start=584
  _FLOATVALUE._serialized_end=611
  _DOUBLEVALUE._serialized_start=613
  _DOUBLEVALUE._serialized_end=641
  _BOOLVALUE._serialized_start=643
  _BOOLVALUE._serialized_end=669
  _LINKINFO._serialized_start=671
  _LINKINFO._serialized_end=722
# @@protoc_insertion_point(module_scope)
